@@ -5,18 +5,20 @@ from sn2.device import (
     Device,
     DeviceInitializationError,
     DeviceUnsupportedError,
+    InformationData,
     InformationUpdate,
     OnOffSetting,
     SettingsUpdate,
     StateChange,
 )
 
-__version__ = "0.1.2"
+__version__ = "0.2.1"
 __all__ = [
     "ConnectionStatus",
     "Device",
     "DeviceInitializationError",
     "DeviceUnsupportedError",
+    "InformationData",
     "InformationUpdate",
     "OnOffSetting",
     "SettingsUpdate",
